@@ -24,6 +24,7 @@
 #include "gnome-db-basic-form.h"
 #include "gnome-db-tools.h"
 #include "marshal.h"
+#include "utility.h"
 #include "gnome-db-data-entry.h"
 #include <libgnomedb/data-entries/gnome-db-entry-combo.h>
 
@@ -138,7 +139,7 @@ gnome_db_basic_form_class_init (GnomeDbBasicFormClass * class)
 			      G_STRUCT_OFFSET (GnomeDbBasicFormClass, param_changed),
 			      NULL, NULL,
 			      marshal_VOID__OBJECT_BOOLEAN, G_TYPE_NONE, 2,
-			      G_TYPE_OBJECT, G_TYPE_BOOLEAN);
+			      GDA_TYPE_PARAMETER, G_TYPE_BOOLEAN);
 	gnome_db_basic_form_signals[ACTIVATED] =
 		g_signal_new ("activated",
 			      G_TYPE_FROM_CLASS (object_class),
@@ -165,12 +166,12 @@ gnome_db_basic_form_class_init (GnomeDbBasicFormClass * class)
                                                                G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (object_class, PROP_HEADERS_SENSITIVE,
 					 g_param_spec_boolean ("headers_sensitive",
-							       _("Entry's headers are sensitive"), 
+							       _("Entry headers are sensitive"), 
 							       NULL, FALSE,
 							       G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (object_class, PROP_SHOW_ACTIONS,
 					 g_param_spec_boolean ("show_actions",
-							       _("Show entries actions"), 
+							       _("Show Entry actions"), 
 							       NULL, FALSE,
 							       G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (object_class, PROP_ENTRIES_AUTO_DEFAULT,
@@ -253,7 +254,7 @@ gnome_db_basic_form_new_custom (GdaParameterList *paramlist, const gchar *glade_
 	spec.form_prefix = (gchar *) form_prefix;
 	obj = g_object_new (GNOME_DB_TYPE_BASIC_FORM, "layout_spec", &spec, "paramlist", paramlist, NULL);
 
-	return (GtkWidget *) obj;	
+	return (GtkWidget *) obj;
 }
 
 
@@ -434,8 +435,8 @@ gnome_db_basic_form_set_property (GObject *object,
 			break;
 		case PROP_PARAMLIST:
 			if (form->priv->paramlist) {
-				TO_IMPLEMENT;
-				g_assert_not_reached ();
+				paramlist_destroyed_cb (form->priv->paramlist, form);
+				gnome_db_basic_form_clean (form);
 			}
 
 			form->priv->paramlist = g_value_get_pointer (value);
@@ -468,7 +469,7 @@ gnome_db_basic_form_set_property (GObject *object,
 			form->priv->headers_sensitive = g_value_get_boolean (value);
 			break;
 		case PROP_SHOW_ACTIONS:
-			gnome_db_basic_form_show_entries_actions(form, g_value_get_boolean(value));
+			gnome_db_basic_form_show_entry_actions(form, g_value_get_boolean(value));
 			break;
 		case PROP_ENTRIES_AUTO_DEFAULT:
 			gnome_db_basic_form_set_entries_auto_default(form, g_value_get_boolean(value));
@@ -861,9 +862,26 @@ gnome_db_basic_form_fill (GnomeDbBasicForm *form)
 	g_object_set_data (G_OBJECT (form), "expand", GINT_TO_POINTER (form_expand));
 	
 	/* Set the Show actions in the entries */
-	gnome_db_basic_form_show_entries_actions(form, form->priv->show_actions);
+	gnome_db_basic_form_show_entry_actions (form, form->priv->show_actions);
 	/* Set the Auto entries default in the entries */
-	gnome_db_basic_form_set_entries_auto_default(form, form->priv->entries_auto_default);
+	gnome_db_basic_form_set_entries_auto_default (form, form->priv->entries_auto_default);
+
+	/* hide some entries if specified */
+	for (list = form->priv->entries; list; list = list->next) {
+		gboolean explicit_hide = FALSE;
+		GdaParameter *param;
+			
+		param = g_object_get_data (G_OBJECT (list->data), "param");
+		if (param) {
+			if (GPOINTER_TO_INT (g_object_get_data (G_OBJECT (param), "_gnome_db_explicit_show")) == 1)
+				explicit_hide = TRUE;
+		}
+		else {
+			/* FIXME */
+		}
+		if (explicit_hide) 
+			gnome_db_basic_form_entry_show (form, param, FALSE);
+	}
 }
 
 static void
@@ -909,14 +927,11 @@ mark_not_null_entry_labels (GnomeDbBasicForm *form, gboolean show_mark)
 		gchar *str;
 
 		title = g_object_get_data (G_OBJECT (list->data), "_gda_title");
-		if (show_mark) {
-			str = g_strdup_printf ("%s <span foreground='red' weight='bold'>*</span>:", title);
+		str = gnome_db_utility_markup_title (title, !show_mark);
+		if (show_mark) 
 			gtk_label_set_markup (GTK_LABEL (list->data), str);
-		}
-		else {
-			str = g_strdup_printf ("%s:", title);
-			gtk_label_set_text (GTK_LABEL (list->data), str);			
-		}
+		else 
+			gtk_label_set_text (GTK_LABEL (list->data), str);
 		g_free (str);
 	}
 }
@@ -937,7 +952,7 @@ static void
 entry_contents_modified (GnomeDbDataEntry *entry, GnomeDbBasicForm *form)
 {
 	GdaParameter *param;
-	guint attr;
+	GdaValueAttribute attr;
 
 	attr = gnome_db_data_entry_get_attributes (entry);
 	param = g_object_get_data (G_OBJECT (entry), "param");
@@ -1249,7 +1264,7 @@ gnome_db_basic_form_has_been_changed (GnomeDbBasicForm *form)
 }
 
 /**
- * gnome_db_basic_form_show_entries_actions
+ * gnome_db_basic_form_show_entry_actions
  * @form: a #GnomeDbBasicForm widget
  * @show_actions: a boolean
  *
@@ -1257,7 +1272,7 @@ gnome_db_basic_form_has_been_changed (GnomeDbBasicForm *form)
  * in the form
  */
 void
-gnome_db_basic_form_show_entries_actions (GnomeDbBasicForm *form, gboolean show_actions)
+gnome_db_basic_form_show_entry_actions (GnomeDbBasicForm *form, gboolean show_actions)
 {
 	GSList *entries;
 	guint show;
