@@ -25,6 +25,7 @@
 #include <gtk/gtknotebook.h>
 #include <gtk/gtkstock.h>
 #include <gtk/gtktable.h>
+#include <gtk/gtkhbox.h>
 #include <gtk/gtkwindow.h>
 #include <libgnomedb/gnome-db-login.h>
 #include <libgnomedb/gnome-db-login-dialog.h>
@@ -96,6 +97,7 @@ gnome_db_login_dialog_init (GnomeDbLoginDialog *dialog, GnomeDbLoginDialogClass
 	GtkWidget *hbox, *vbox, *image, *label;
 	GtkWidget *nb;
 	gchar *str;
+	GdkPixbuf *icon;
 
 	g_return_if_fail (GNOME_DB_IS_LOGIN_DIALOG (dialog));
 
@@ -115,10 +117,10 @@ gnome_db_login_dialog_init (GnomeDbLoginDialog *dialog, GnomeDbLoginDialogClass
 	gtk_widget_show (hbox);
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), hbox, TRUE, TRUE, 0);
 
-	image = gtk_image_new_from_file (LIBGNOMEDB_ICONSDIR "/gnome-db-database-login_48x48.png");
+	image = gtk_image_new_from_stock (GTK_STOCK_DIALOG_AUTHENTICATION, GTK_ICON_SIZE_DIALOG);
         gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0.0);
 	gtk_widget_show (image);
-	gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 5);
 
 	nb = gtk_notebook_new ();
 	gtk_notebook_set_show_tabs (GTK_NOTEBOOK (nb), FALSE);
@@ -149,6 +151,13 @@ gnome_db_login_dialog_init (GnomeDbLoginDialog *dialog, GnomeDbLoginDialogClass
 	gnome_db_login_set_enable_create_button (GNOME_DB_LOGIN (dialog->priv->login), TRUE);
 	gtk_widget_show (dialog->priv->login);
 	gtk_box_pack_start (GTK_BOX (vbox), dialog->priv->login, TRUE, TRUE, 0);
+
+	icon = gdk_pixbuf_new_from_file (LIBGNOMEDB_ICONSDIR "/gnome-db.png", NULL);
+	if (icon) {
+		gtk_window_set_icon (GTK_WINDOW (dialog), icon);
+		g_object_unref (icon);
+	}
+
 }
 
 static void
@@ -247,17 +256,9 @@ gnome_db_login_dialog_get_type (void)
 GtkWidget *
 gnome_db_login_dialog_new (const gchar *title)
 {
-	GdkPixbuf *icon;
 	GnomeDbLoginDialog *dialog;
 
-	dialog = g_object_new (GNOME_DB_TYPE_LOGIN_DIALOG, NULL);
-	gtk_window_set_title (GTK_WINDOW (dialog), title);
-
-	icon = gdk_pixbuf_new_from_file (LIBGNOMEDB_ICONSDIR "/gnome-db.png", NULL);
-	if (icon) {
-		gtk_window_set_icon (GTK_WINDOW (dialog), icon);
-		g_object_unref (icon);
-	}
+	dialog = g_object_new (GNOME_DB_TYPE_LOGIN_DIALOG, "title", title, NULL);
 
 	return GTK_WIDGET (dialog);
 }
@@ -338,3 +339,4 @@ gnome_db_login_dialog_get_login_widget (GnomeDbLoginDialog *dialog)
 	g_return_val_if_fail (GNOME_DB_IS_LOGIN_DIALOG (dialog), NULL);
 	return dialog->priv->login;
 }
+
