@@ -1,8 +1,9 @@
 /* GNOME DB library
- * Copyright (C) 1999 - 2005 The GNOME Foundation.
+ * Copyright (C) 1999 - 2006 The GNOME Foundation.
  *
  * AUTHORS:
  * 	Rodrigo Moya <rodrigo@gnome-db.org>
+ *      vivien Malerba <malerba@gnome-db.org>
  *
  * This Library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public License as
@@ -24,6 +25,7 @@
 #include <gtk/gtkstock.h>
 #include <libgnomedb/gnome-db-stock.h>
 #include <glib/gi18n-lib.h>
+#include <libgda/gda-log.h>
 
 static GtkStockItem builtin_icons [] = {
 	{ GNOME_DB_STOCK_AGGREGATES, N_("Aggregates"), 0, 0, GETTEXT_PACKAGE },
@@ -41,6 +43,7 @@ static GtkStockItem builtin_icons [] = {
 	{ GNOME_DB_STOCK_TABLES, N_("Tables"), 0, 0, GETTEXT_PACKAGE },
 	{ GNOME_DB_STOCK_TYPES, N_("Types"), 0, 0, GETTEXT_PACKAGE },
 	{ GNOME_DB_STOCK_WITHIN_TRANSACTION, N_("WithinTransaction"), 0, 0, GETTEXT_PACKAGE },
+	{ GNOME_DB_STOCK_SQL_CONSOLE, N_("SQLConsole"), 0, 0, GETTEXT_PACKAGE },
 };
 
 void gnome_db_stock_init (void);
@@ -90,7 +93,7 @@ get_stock_icons (GtkIconFactory *factory)
 		   GTK_ICON_SIZE_BUTTON, GNOME_DB_STOCK_COMMIT);
 	add_sized (factory, LIBGNOMEDB_ICONSDIR "/gnome-db-connect_24x24.png",
 		   GTK_ICON_SIZE_BUTTON, GNOME_DB_STOCK_CONNECT);
-	add_sized (factory, LIBGNOMEDB_ICONSDIR "/gnome-db-database_24x24.png",
+	add_sized (factory, LIBGNOMEDB_ICONSDIR "/gda-dict-database_24x24.png",
 		   GTK_ICON_SIZE_BUTTON, GNOME_DB_STOCK_DATABASE);
 	add_sized (factory,  LIBGNOMEDB_ICONSDIR "/gnome-db-designer_24x24.png",
 		   GTK_ICON_SIZE_BUTTON, GNOME_DB_STOCK_DESIGNER);
@@ -100,7 +103,7 @@ get_stock_icons (GtkIconFactory *factory)
 		   GTK_ICON_SIZE_BUTTON, GNOME_DB_STOCK_NO_TRANSACTION);
 	add_sized (factory, LIBGNOMEDB_ICONSDIR "/gnome-db-procedures_24x24.png",
 		   GTK_ICON_SIZE_BUTTON, GNOME_DB_STOCK_PROCEDURES);
-	add_sized (factory, LIBGNOMEDB_ICONSDIR "/gnome-db-query_24x24.png",
+	add_sized (factory, LIBGNOMEDB_ICONSDIR "/gda-query_24x24.png",
 		   GTK_ICON_SIZE_BUTTON, GNOME_DB_STOCK_QUERY);
 	add_sized (factory, LIBGNOMEDB_ICONSDIR "/gnome-db-rollback_24x24.png",
 		   GTK_ICON_SIZE_BUTTON, GNOME_DB_STOCK_ROLLBACK);
@@ -108,7 +111,7 @@ get_stock_icons (GtkIconFactory *factory)
 		   GTK_ICON_SIZE_BUTTON, GNOME_DB_STOCK_SEQUENCES);
 	add_sized (factory,  LIBGNOMEDB_ICONSDIR "/gnome-db-sql_24x24.png",
 		   GTK_ICON_SIZE_BUTTON, GNOME_DB_STOCK_SQL);
-	add_sized (factory,  LIBGNOMEDB_ICONSDIR "/gnome-db-tables_24x24.png",
+	add_sized (factory,  LIBGNOMEDB_ICONSDIR "/gda-dict-tables_24x24.png",
 		   GTK_ICON_SIZE_BUTTON, GNOME_DB_STOCK_TABLES);
 	add_sized (factory, LIBGNOMEDB_ICONSDIR "/gnome-db-types_24x24.png",
 		   GTK_ICON_SIZE_BUTTON, GNOME_DB_STOCK_TYPES);
@@ -116,6 +119,8 @@ get_stock_icons (GtkIconFactory *factory)
 		   GTK_ICON_SIZE_BUTTON, GNOME_DB_STOCK_WITHIN_TRANSACTION);
 	add_sized (factory, LIBGNOMEDB_ICONSDIR "/gnome-db-relations_24x24.png",
                    GTK_ICON_SIZE_BUTTON, GNOME_DB_STOCK_RELATIONS);
+	add_sized (factory, LIBGNOMEDB_ICONSDIR "/gnome-db-console_24x24.png",
+                   GTK_ICON_SIZE_BUTTON, GNOME_DB_STOCK_SQL_CONSOLE);
 }
 
 /**
