@@ -57,25 +57,17 @@
 #include <libgnomedb/gnome-db-form.h>
 #include <libgnomedb/gnome-db-data-import.h>
 #include <libgnomedb/gnome-db-data-widget-info.h>
-#include <libgnomedb/gnome-db-dbms-update-viewer.h>
 #include <libgnomedb/gnome-db-dsn-editor.h>
 #include <libgnomedb/gnome-db-dsn-spec.h>
-#include <libgnomedb/gnome-db-editor.h>
 #include <libgnomedb/gnome-db-raw-form.h>
 #include <libgnomedb/gnome-db-raw-grid.h>
 #include <libgnomedb/gnome-db-grid.h>
-#include <libgnomedb/gnome-db-error-dialog.h>
-#include <libgnomedb/gnome-db-error.h>
 #include <libgnomedb/gnome-db-find-dialog.h>
-#include <libgnomedb/gnome-db-gray-bar.h>
 #include <libgnomedb/gnome-db-login-dialog.h>
 #include <libgnomedb/gnome-db-login.h>
 #include <libgnomedb/gnome-db-provider-selector.h>
-#include <libgnomedb/gnome-db-report-editor.h>
 #include <libgnomedb/gnome-db-stock.h>
-#include <libgnomedb/gnome-db-selector.h>
 #include <libgnomedb/gnome-db-server-operation.h>
-#include <libgnomedb/gnome-db-sql-console.h>
 #include <libgnomedb/gnome-db-transaction-status.h>
 #include <libgnomedb/gnome-db-dsn-assistant.h>
 
