@@ -1,9 +1,13 @@
 #include <glib/gi18n-lib.h>
 #include <libgnomedb/libgnomedb.h>
+#include <libgnomedb-extra/libgnomedb-extra.h>
 #include <gtk/gtk.h>
 #include <unistd.h>
 #include <string.h>
+#ifdef HAVE_LIBGNOMECANVAS
+#include <libgnomedb-graph/libgnomedb-graph.h>
 #include <libgda/graph/gda-dict-reg-graphs.h>
+#endif
 
 #define SQL_QUERY_ROWS "SELECT c.name, o.creation_date FROM orders o INNER JOIN customers c ON (c.id=o.customer) ORDER BY c.name, o.creation_date"
 #define SQL_QUERY_COLS "SELECT p.name, p.price FROM products p ORDER BY p.name, p.price"
@@ -77,10 +81,16 @@ static void          param_list_param_changed_cb (GdaParameterList *paramlist, G
 /*
  * list of tests' functions
  */
+#ifdef HAVE_LIBGNOMECANVAS
 static GtkWidget *rels_graph_test_make   (MainConfig *config);
 static void       rels_graph_test_clean  (MainConfig *config, GtkWidget *test_widget);
 static gboolean   rels_graph_test_signal (MainConfig *config, GtkWidget *test_widget);
 
+static GtkWidget *query_graph_test_make   (MainConfig *config);
+static void       query_graph_test_clean  (MainConfig *config, GtkWidget *test_widget);
+static gboolean   query_graph_test_signal (MainConfig *config, GtkWidget *test_widget);
+#endif
+
 static GtkWidget *form_grid_test_make_form (MainConfig *config);
 static GtkWidget *form_grid_test_make_grid (MainConfig *config);
 static void       form_grid_test_clean     (MainConfig *config, GtkWidget *test_widget);
@@ -94,10 +104,6 @@ static GtkWidget *selector_test_make   (MainConfig *config);
 static void       selector_test_clean  (MainConfig *config, GtkWidget *test_widget);
 static gboolean   selector_test_signal (MainConfig *config, GtkWidget *test_widget);
 
-static GtkWidget *query_graph_test_make   (MainConfig *config);
-static void       query_graph_test_clean  (MainConfig *config, GtkWidget *test_widget);
-static gboolean   query_graph_test_signal (MainConfig *config, GtkWidget *test_widget);
-
 static GtkWidget *dsn_selector_test_make   (MainConfig *config);
 
 static GtkWidget *editor_test_make   (MainConfig *config);
@@ -145,6 +151,7 @@ build_tests (MainConfig *config)
 	test->signal_conn_changed = NULL;
 	list = g_slist_append (list, test);
 
+#ifdef HAVE_LIBGNOMECANVAS
 	/* GnomeDbCanvasDbRelations test */
 	test = g_new0 (ATest, 1);
 	test->test_name = "GnomeDbCanvasDbRelations";
@@ -154,15 +161,6 @@ build_tests (MainConfig *config)
 	test->signal_conn_changed = rels_graph_test_signal;
 	list = g_slist_append (list, test);
 
-	/* GnomeDbSelector test */
-	test = g_new0 (ATest, 1);
-	test->test_name = "GnomeDbSelector";
-	test->test_descr = "";
-	test->make_test_widget = selector_test_make;
-	test->clean_data = selector_test_clean;
-	test->signal_conn_changed = selector_test_signal;
-	list = g_slist_append (list, test);
-
 	/* GnomeDbCanvasQueryStruct test */
 	test = g_new0 (ATest, 1);
 	test->test_name = "GnomeDbCanvasQueryStruct";
@@ -171,6 +169,16 @@ build_tests (MainConfig *config)
 	test->clean_data = query_graph_test_clean;
 	test->signal_conn_changed = query_graph_test_signal;
 	list = g_slist_append (list, test);
+#endif
+
+	/* GnomeDbSelector test */
+	test = g_new0 (ATest, 1);
+	test->test_name = "GnomeDbSelector";
+	test->test_descr = "";
+	test->make_test_widget = selector_test_make;
+	test->clean_data = selector_test_clean;
+	test->signal_conn_changed = selector_test_signal;
+	list = g_slist_append (list, test);
 
 	/* GnomeDbDataSourceSelector test */
 	test = g_new0 (ATest, 1);
@@ -1072,7 +1080,7 @@ param_list_param_changed_cb (GdaParameterList *paramlist, GdaParameter *param, g
 
 
 
-
+#ifdef HAVE_LIBGNOMECANVAS
 /*
  * GnomeDbCanvasDbRelations test
  */
@@ -1215,7 +1223,7 @@ query_graph_test_signal (MainConfig *config, GtkWidget *test_widget)
 
 	return TRUE;
 }
-
+#endif
 
 /*
  * GnomeDbForm and GnomeDbGrid tests
@@ -1229,6 +1237,73 @@ typedef struct {
 } TestData3;
 
 static void form_grid_selected_obj_changed (GnomeDbSelector *mgsel, GObject *obj, TestData3 *data);
+static void form_grid_option_toggled_cb (GtkWidget *radio, TestData3 *data);
+static GtkWidget *
+form_grid_test_make_options (TestData3 *data)
+{
+	GtkWidget *table, *wid, *radio;
+
+	table = gtk_table_new (5, 2, FALSE);
+	wid = gtk_label_new ("<b>Select write mode</b>");
+	gtk_label_set_use_markup (GTK_LABEL (wid), TRUE);
+	gtk_table_attach (GTK_TABLE (table), wid, 0, 2, 0, 1, GTK_FILL, 0, 0, 0);
+
+	wid = gtk_label_new ("GNOME_DB_DATA_WIDGET_WRITE_ON_DEMAND");
+	gtk_misc_set_alignment (GTK_MISC (wid), 0., 0.);
+	gtk_table_attach (GTK_TABLE (table), wid, 0, 1, 1, 2, GTK_FILL, 0, 0, 0);
+	radio = gtk_radio_button_new (NULL);
+	gtk_table_attach (GTK_TABLE (table), radio, 1, 2, 1, 2, GTK_FILL, 0, 0, 0);
+	g_object_set_data (G_OBJECT (radio), "mode", GINT_TO_POINTER (GNOME_DB_DATA_WIDGET_WRITE_ON_DEMAND));
+	g_signal_connect (G_OBJECT (radio), "toggled", G_CALLBACK (form_grid_option_toggled_cb), data);
+
+	wid = gtk_label_new ("GNOME_DB_DATA_WIDGET_WRITE_ON_ROW_CHANGE");
+	gtk_misc_set_alignment (GTK_MISC (wid), 0., 0.);
+	gtk_table_attach (GTK_TABLE (table), wid, 0, 1, 2, 3, GTK_FILL, 0, 0, 0);
+	radio = gtk_radio_button_new_from_widget (GTK_RADIO_BUTTON (radio));
+	gtk_table_attach (GTK_TABLE (table), radio, 1, 2, 2, 3, GTK_FILL, 0, 0, 0);
+	g_object_set_data (G_OBJECT (radio), "mode", GINT_TO_POINTER (GNOME_DB_DATA_WIDGET_WRITE_ON_ROW_CHANGE));
+	g_signal_connect (G_OBJECT (radio), "toggled", G_CALLBACK (form_grid_option_toggled_cb), data);
+
+	wid = gtk_label_new ("GNOME_DB_DATA_WIDGET_WRITE_ON_VALUE_ACTIVATED");
+	gtk_misc_set_alignment (GTK_MISC (wid), 0., 0.);
+	gtk_table_attach (GTK_TABLE (table), wid, 0, 1, 3, 4, GTK_FILL, 0, 0, 0);
+	radio = gtk_radio_button_new_from_widget (GTK_RADIO_BUTTON (radio));
+	gtk_table_attach (GTK_TABLE (table), radio, 1, 2, 3, 4, GTK_FILL, 0, 0, 0);
+	g_object_set_data (G_OBJECT (radio), "mode", GINT_TO_POINTER (GNOME_DB_DATA_WIDGET_WRITE_ON_VALUE_ACTIVATED));
+	g_signal_connect (G_OBJECT (radio), "toggled", G_CALLBACK (form_grid_option_toggled_cb), data);
+
+	wid = gtk_label_new ("GNOME_DB_DATA_WIDGET_WRITE_ON_VALUE_CHANGE");
+	gtk_misc_set_alignment (GTK_MISC (wid), 0., 0.);
+	gtk_table_attach (GTK_TABLE (table), wid, 0, 1, 4, 5, GTK_FILL, 0, 0, 0);
+	radio = gtk_radio_button_new_from_widget (GTK_RADIO_BUTTON (radio));
+	gtk_table_attach (GTK_TABLE (table), radio, 1, 2, 4, 5, GTK_FILL, 0, 0, 0);
+	g_object_set_data (G_OBJECT (radio), "mode", GINT_TO_POINTER (GNOME_DB_DATA_WIDGET_WRITE_ON_VALUE_CHANGE));
+	g_signal_connect (G_OBJECT (radio), "toggled", G_CALLBACK (form_grid_option_toggled_cb), data);
+	
+	return table;
+}
+
+static void
+form_grid_option_toggled_cb (GtkWidget *radio, TestData3 *data)
+{
+	GnomeDbDataWidgetWriteMode mode;
+	GnomeDbDataWidget *datawid = NULL;
+
+	if (! gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (radio)))
+		return;
+
+	if (GNOME_DB_IS_FORM (data->wid))
+		g_object_get (G_OBJECT (data->wid), "raw_form", &datawid, NULL);
+	else if (GNOME_DB_IS_GRID (data->wid))
+		g_object_get (G_OBJECT (data->wid), "raw_grid", &datawid, NULL);
+	if (!datawid)
+		return;
+
+	mode = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (radio), "mode"));
+	g_print ("Write mode set to %d: %s\n", mode,
+		 gnome_db_data_widget_set_write_mode (datawid, mode) ? "Ok" : "Not Ok");
+	g_object_unref (datawid);
+}
 
 static GtkWidget *
 form_grid_test_make_form (MainConfig *config)
@@ -1237,19 +1312,25 @@ form_grid_test_make_form (MainConfig *config)
 	TestData3 *data;
 	
 	ret = gtk_vbox_new (FALSE, 0);
-	wid = gtk_label_new ("Select a table");
-	gtk_box_pack_start (GTK_BOX (ret), wid, TRUE, TRUE, 0);
-	gtk_widget_show (wid);
 
 	/* private test data */
 	data = g_new0 (TestData3, 1);
 	data->vbox = ret;
-	data->nodata = wid;
 	data->wid = NULL;
 	data->is_grid = FALSE;
 	data->signal_handler = g_signal_connect (G_OBJECT (config->selector), "selection_changed",
 						 G_CALLBACK (form_grid_selected_obj_changed), data);
 	g_object_set_data (G_OBJECT (ret), "private_data", data);
+
+	wid = form_grid_test_make_options (data);
+	gtk_box_pack_start (GTK_BOX (ret), wid, FALSE, FALSE, 0);
+	gtk_widget_show_all (wid);
+
+	wid = gtk_label_new ("Select a table");
+	gtk_box_pack_start (GTK_BOX (ret), wid, TRUE, TRUE, 0);
+	gtk_widget_show (wid);
+	data->nodata = wid;
+
 	form_grid_test_signal (config, ret);
 
 	return ret;
@@ -1261,9 +1342,6 @@ form_grid_test_make_grid (MainConfig *config)
 	TestData3 *data;
 	
 	ret = gtk_vbox_new (FALSE, 0);
-	wid = gtk_label_new ("Select a table");
-	gtk_box_pack_start (GTK_BOX (ret), wid, TRUE, TRUE, 0);
-	gtk_widget_show (wid);
 
 	/* private test data */
 	data = g_new0 (TestData3, 1);
@@ -1274,6 +1352,16 @@ form_grid_test_make_grid (MainConfig *config)
 	data->signal_handler = g_signal_connect (G_OBJECT (config->selector), "selection_changed",
 						 G_CALLBACK (form_grid_selected_obj_changed), data);
 	g_object_set_data (G_OBJECT (ret), "private_data", data);
+
+	wid = form_grid_test_make_options (data);
+	gtk_box_pack_start (GTK_BOX (ret), wid, FALSE, FALSE, 0);
+	gtk_widget_show_all (wid);
+
+	wid = gtk_label_new ("Select a table");
+	gtk_box_pack_start (GTK_BOX (ret), wid, TRUE, TRUE, 0);
+	gtk_widget_show (wid);
+	data->nodata = wid;
+
 	form_grid_test_signal (config, ret);
 
 	return ret;	
@@ -1491,17 +1579,17 @@ cust_forms_grids_test_prepare (MainConfig *config, TestData4 *data)
 	cust_model = gda_data_model_query_new (query);
 	if (!gda_data_model_query_set_modification_query (GDA_DATA_MODEL_QUERY (cust_model),
 							  "UPDATE customers set "
-							  "id=##[:name='+0' :type='gint'], "
-							  "name=##[:name='+1' :type='gchararray'], "
-							  "default_served_by=##[:name='+2' :type='gint'] "
-							  "WHERE id=##[:name='-0' :type='gint']", &error)) {
+							  "id=##/*name:'+0' type:gint*/, "
+							  "name=##/*name:'+1' type:gchararray*/, "
+							  "default_served_by=##/*name:'+2' type:gint*/ "
+							  "WHERE id=##/*name:'-0' type:gint*/", &error)) {
 		g_print ("Error in test code: %s\n",
 			 error && error->message ? error->message : "No detail");
 		g_error_free (error);
 	}
 	if (!gda_data_model_query_set_modification_query (GDA_DATA_MODEL_QUERY (cust_model),
 							  "DELETE from customers "
-							  "WHERE id=##[:name='-0' :type='gint']", &error)) {
+							  "WHERE id=##/*name:'-0' type:gint*/", &error)) {
 		g_print ("Error in test code: %s\n",
 			 error && error->message ? error->message : "No detail");
 		g_error_free (error);
@@ -1509,9 +1597,9 @@ cust_forms_grids_test_prepare (MainConfig *config, TestData4 *data)
 	if (!gda_data_model_query_set_modification_query (GDA_DATA_MODEL_QUERY (cust_model),
 							  "INSERT INTO customers (id, name, default_served_by) "
 							  "values ("
-							  "##[:name='+0' :type='gint'], "
-							  "##[:name='+1' :type='gchararray'], "
-							  "##[:name='+2' :type='gint'])",
+							  "##/*name:'+0' type:gint*/, "
+							  "##/*name:'+1' type:gchararray*/, "
+							  "##/*name:'+2' type:gint*/)",
 							  &error)) {
 		g_print ("Error in test code: %s\n",
 			 error && error->message ? error->message : "No detail");
@@ -1575,7 +1663,7 @@ cust_forms_grids_test_prepare (MainConfig *config, TestData4 *data)
 	g_object_get (G_OBJECT (wid), "raw_form", &raw_form, NULL);
 
 	iter = gnome_db_data_widget_get_current_data (GNOME_DB_DATA_WIDGET (raw_form));
-	/* gnome_db_basic_form_show_entries_actions (GNOME_DB_BASIC_FORM (raw_form), TRUE); */
+	/* gnome_db_basic_form_show_entry_actions (GNOME_DB_BASIC_FORM (raw_form), TRUE); */
 	data->form_iter = iter;
 	param = g_slist_nth_data (GDA_PARAMETER_LIST (iter)->parameters, 2);
 	if (!gda_parameter_restrict_values (param, sr_model, 0, &error)) {
